==> ruly-0.0.7-py3-none-any.whl: ruly/common.py <==
import abc
from collections import namedtuple
import enum


class Rule(namedtuple('Rule', ['antecedent', 'consequent'])):
    """Knowledge base rule

    Attributes:
        antecedent (Union[ruly.Condition, ruly.Expression]): expression or a
            condition that, if evaluated to True, fires assignment defined by
            the consequent
        consenquent (Dict[str, Any]): keys are variable names, values are
            values assigned if rule fires
    """

    def __str__(self):
        consequent = ' AND '.join(
            f'{k} = {v}' for k, v in self.consequent.items())
        return f'IF {self.antecedent} THEN {consequent}'


class Operator(enum.Enum):
    AND = 1


class Expression(namedtuple('Expression', ['operator', 'children'])):
    """Logical expression, aggregation of conditions and
    sub-expressions

    Attributes:
        operator (ruly.Operator): operator applied to all children when
            evaluated
        children (List[Union[ruly.Condition, ruly.Expression]]): list of
            conditions or other expressions
    """

    def __str__(self):
        return f' {self.operator.name} '.join([str(c) for c in self.children])


class Condition(abc.ABC):
    """Abstract class representing a condition that needs to be satisfied when
    evaluating an expression."""

    @abc.abstractmethod
    def satisfied(self, value):
        """Checks whether the condition is satisfied for the given value

        Args:
            value (Any): checked value

        Returns:
            bool: true if condition is satisfied, false otherwise"""


class Evaluation(namedtuple('Evaluation', ['state', 'unknowns'])):
    """Structure representing an evaluation result

    Attributes:
        state (Dict[str, Any]: values): all variable values
        unknowns (Set[Unknown]): set of all found unknowns"""


def get_rule_depending_variables(rule):
    """Calculate all input variables in a rule

    Returns:
        List[str]: names of all input variables"""
    if isinstance(rule.antecedent, Condition):
        return set([rule.antecedent.name])
    elif isinstance(rule.antecedent, Expression):
        return set([c.name for c in rule.antecedent.children])

==> ruly-0.1.0-py3-none-any.whl: ruly/common.py <==
import abc
from dataclasses import dataclass
import enum
from typing import Union, Dict, Any, List, Sequence


class Operator(enum.Enum):
    AND = 1


@dataclass
class Condition(abc.ABC):
    """Abstract class representing a condition that needs to be satisfied when
    evaluating an expression.

    Attributes:
        name (str): variable name
    """
    name: str

    @abc.abstractmethod
    def satisfied(self, value):
        """Checks whether the condition is satisfied for the given value

        Args:
            value (Any): checked value

        Returns:
            bool: true if condition is satisfied, false otherwise"""


@dataclass
class Expression:
    """Logical expression, aggregation of conditions and
    sub-expressions

    Attributes:
        operator (ruly.Operator): operator applied to all children when
            evaluated
        children (List[Union[ruly.Condition, ruly.Expression]]): list of
            conditions or other expressions
    """
    operator: Operator
    children: Sequence[Union[Condition, "Expression"]]

    def __str__(self):
        return f" {self.operator.name} ".join([str(c) for c in self.children])


@dataclass
class Rule:
    """Knowledge base rule

    Attributes:
        antecedent (Union[ruly.Condition, ruly.Expression]): expression or a
            condition that, if evaluated to True, fires assignment defined by
            the consequent.
        consequent (Dict[str, Any]): keys are variable names, values are
            values assigned if rule fires
    """
    antecedent: Union[Condition, Expression]
    consequent: Dict[str, Any]

    def __str__(self):
        consequent = " AND ".join(
            f"{k} = {v}" for k, v in self.consequent.items()
        )
        return f"IF {self.antecedent} THEN {consequent}"


def get_rule_depending_variables(rule):
    """Calculate all input variables in a rule

    Returns:
        List[str]: names of all input variables"""
    if isinstance(rule.antecedent, Condition):
        return {rule.antecedent.name}
    elif isinstance(rule.antecedent, Expression):
        return set([c.name for c in rule.antecedent.children])
